summaryrefslogtreecommitdiffstats
path: root/kpdf
diff options
context:
space:
mode:
Diffstat (limited to 'kpdf')
-rw-r--r--kpdf/conf/dlgaccessibility.ui26
-rw-r--r--kpdf/conf/dlggeneral.ui8
-rw-r--r--kpdf/conf/dlgperformance.ui16
-rw-r--r--kpdf/conf/dlgpresentation.ui4
-rw-r--r--kpdf/core/document.cpp18
-rw-r--r--kpdf/core/generator_pdf/generator_pdf.cpp26
-rw-r--r--kpdf/core/link.cpp4
-rw-r--r--kpdf/core/page.cpp6
-rw-r--r--kpdf/core/page.h2
-rw-r--r--kpdf/core/pagetransition.cpp2
-rw-r--r--kpdf/core/pagetransition.h6
-rw-r--r--kpdf/error.cpp2
-rw-r--r--kpdf/part.cpp24
-rw-r--r--kpdf/ui/minibar.cpp22
-rw-r--r--kpdf/ui/pagepainter.cpp8
-rw-r--r--kpdf/ui/pageview.cpp114
-rw-r--r--kpdf/ui/pageviewutils.cpp42
-rw-r--r--kpdf/ui/pageviewutils.h6
-rw-r--r--kpdf/ui/presentationwidget.cpp88
-rw-r--r--kpdf/ui/presentationwidget.h2
-rw-r--r--kpdf/ui/propertiesdialog.cpp24
-rw-r--r--kpdf/ui/searchwidget.cpp4
-rw-r--r--kpdf/ui/thumbnaillist.cpp12
-rw-r--r--kpdf/ui/thumbnaillist.h2
24 files changed, 234 insertions, 234 deletions
diff --git a/kpdf/conf/dlgaccessibility.ui b/kpdf/conf/dlgaccessibility.ui
index 9d7b9da2..9bb5d46e 100644
--- a/kpdf/conf/dlgaccessibility.ui
+++ b/kpdf/conf/dlgaccessibility.ui
@@ -138,7 +138,7 @@
</widget>
<widget class="TQLayoutWidget">
<property name="name">
- <cstring>tqlayout5</cstring>
+ <cstring>layout5</cstring>
</property>
<hbox>
<property name="name">
@@ -154,7 +154,7 @@
<property name="sizeType">
<enum>Fixed</enum>
</property>
- <property name="tqsizeHint">
+ <property name="sizeHint">
<size>
<width>16</width>
<height>20</height>
@@ -196,7 +196,7 @@
<property name="sizeType">
<enum>Expanding</enum>
</property>
- <property name="tqsizeHint">
+ <property name="sizeHint">
<size>
<width>30</width>
<height>20</height>
@@ -215,7 +215,7 @@
</widget>
<widget class="TQLayoutWidget">
<property name="name">
- <cstring>tqlayout2</cstring>
+ <cstring>layout2</cstring>
</property>
<grid>
<property name="name">
@@ -234,7 +234,7 @@
<property name="sizeType">
<enum>Expanding</enum>
</property>
- <property name="tqsizeHint">
+ <property name="sizeHint">
<size>
<width>48</width>
<height>21</height>
@@ -262,7 +262,7 @@
<property name="sizeType">
<enum>Fixed</enum>
</property>
- <property name="tqsizeHint">
+ <property name="sizeHint">
<size>
<width>16</width>
<height>20</height>
@@ -290,7 +290,7 @@
<property name="sizeType">
<enum>Expanding</enum>
</property>
- <property name="tqsizeHint">
+ <property name="sizeHint">
<size>
<width>48</width>
<height>21</height>
@@ -318,7 +318,7 @@
<property name="sizeType">
<enum>Fixed</enum>
</property>
- <property name="tqsizeHint">
+ <property name="sizeHint">
<size>
<width>16</width>
<height>20</height>
@@ -348,7 +348,7 @@
</widget>
<widget class="TQLayoutWidget">
<property name="name">
- <cstring>tqlayout5</cstring>
+ <cstring>layout5</cstring>
</property>
<grid>
<property name="name">
@@ -375,7 +375,7 @@
<property name="sizeType">
<enum>Expanding</enum>
</property>
- <property name="tqsizeHint">
+ <property name="sizeHint">
<size>
<width>48</width>
<height>21</height>
@@ -392,7 +392,7 @@
<property name="sizeType">
<enum>Fixed</enum>
</property>
- <property name="tqsizeHint">
+ <property name="sizeHint">
<size>
<width>16</width>
<height>20</height>
@@ -409,7 +409,7 @@
<property name="sizeType">
<enum>Fixed</enum>
</property>
- <property name="tqsizeHint">
+ <property name="sizeHint">
<size>
<width>16</width>
<height>20</height>
@@ -426,7 +426,7 @@
<property name="sizeType">
<enum>Expanding</enum>
</property>
- <property name="tqsizeHint">
+ <property name="sizeHint">
<size>
<width>48</width>
<height>21</height>
diff --git a/kpdf/conf/dlggeneral.ui b/kpdf/conf/dlggeneral.ui
index b042d261..430f3dfb 100644
--- a/kpdf/conf/dlggeneral.ui
+++ b/kpdf/conf/dlggeneral.ui
@@ -32,7 +32,7 @@
</property>
<widget class="TQLayoutWidget">
<property name="name">
- <cstring>tqlayout4</cstring>
+ <cstring>layout4</cstring>
</property>
<vbox>
<property name="name">
@@ -96,7 +96,7 @@
</widget>
<widget class="TQLayoutWidget">
<property name="name">
- <cstring>tqlayout3_2</cstring>
+ <cstring>layout3_2</cstring>
</property>
<vbox>
<property name="name">
@@ -128,7 +128,7 @@
<property name="sizeType">
<enum>Minimum</enum>
</property>
- <property name="tqsizeHint">
+ <property name="sizeHint">
<size>
<width>20</width>
<height>1</height>
@@ -149,7 +149,7 @@
<property name="sizeType">
<enum>Expanding</enum>
</property>
- <property name="tqsizeHint">
+ <property name="sizeHint">
<size>
<width>20</width>
<height>20</height>
diff --git a/kpdf/conf/dlgperformance.ui b/kpdf/conf/dlgperformance.ui
index dab4ffcc..3676c3ba 100644
--- a/kpdf/conf/dlgperformance.ui
+++ b/kpdf/conf/dlgperformance.ui
@@ -40,7 +40,7 @@
</property>
<widget class="TQLayoutWidget">
<property name="name">
- <cstring>tqlayout9</cstring>
+ <cstring>layout9</cstring>
</property>
<vbox>
<property name="name">
@@ -66,7 +66,7 @@
</widget>
<widget class="TQLayoutWidget">
<property name="name">
- <cstring>tqlayout6_2</cstring>
+ <cstring>layout6_2</cstring>
</property>
<vbox>
<property name="name">
@@ -98,7 +98,7 @@
<property name="sizeType">
<enum>Minimum</enum>
</property>
- <property name="tqsizeHint">
+ <property name="sizeHint">
<size>
<width>21</width>
<height>1</height>
@@ -138,13 +138,13 @@
<property name="textFormat">
<enum>PlainText</enum>
</property>
- <property name="tqalignment">
+ <property name="alignment">
<set>WordBreak|AlignVCenter</set>
</property>
</widget>
<widget class="TQLayoutWidget" row="0" column="0">
<property name="name">
- <cstring>tqlayout5</cstring>
+ <cstring>layout5</cstring>
</property>
<vbox>
<property name="name">
@@ -178,7 +178,7 @@
</widget>
<widget class="TQLayoutWidget" row="0" column="1">
<property name="name">
- <cstring>tqlayout6</cstring>
+ <cstring>layout6</cstring>
</property>
<vbox>
<property name="name">
@@ -210,7 +210,7 @@
<property name="sizeType">
<enum>Minimum</enum>
</property>
- <property name="tqsizeHint">
+ <property name="sizeHint">
<size>
<width>21</width>
<height>1</height>
@@ -231,7 +231,7 @@
<property name="sizeType">
<enum>Expanding</enum>
</property>
- <property name="tqsizeHint">
+ <property name="sizeHint">
<size>
<width>21</width>
<height>16</height>
diff --git a/kpdf/conf/dlgpresentation.ui b/kpdf/conf/dlgpresentation.ui
index 8d3a6c8c..d011c2b3 100644
--- a/kpdf/conf/dlgpresentation.ui
+++ b/kpdf/conf/dlgpresentation.ui
@@ -32,7 +32,7 @@
</property>
<widget class="TQLayoutWidget">
<property name="name">
- <cstring>tqlayout1</cstring>
+ <cstring>layout1</cstring>
</property>
<grid>
<property name="name">
@@ -258,7 +258,7 @@
<property name="sizeType">
<enum>Expanding</enum>
</property>
- <property name="tqsizeHint">
+ <property name="sizeHint">
<size>
<width>20</width>
<height>1</height>
diff --git a/kpdf/core/document.cpp b/kpdf/core/document.cpp
index 2074789d..c85dcea9 100644
--- a/kpdf/core/document.cpp
+++ b/kpdf/core/document.cpp
@@ -13,7 +13,7 @@
#include <tqfile.h>
#include <tqfileinfo.h>
#include <tqimage.h>
-#include <tqtextstream.h>
+#include <textstream.h>
#include <tqvaluevector.h>
#include <tqtimer.h>
#include <tqmap.h>
@@ -118,7 +118,7 @@ KPDFDocument::KPDFDocument(TQWidget *widget)
TQStringList::Iterator it = list.begin();
while( it != list.end() )
{
- d->kimgioMimes << KMimeType::findByPath(TQString("foo.%1").tqarg(*it), 0, true)->name();
+ d->kimgioMimes << KMimeType::findByPath(TQString("foo.%1").arg(*it), 0, true)->name();
++it;
}
}
@@ -331,7 +331,7 @@ void KPDFDocument::reparseConfig()
// reparse generator config and if something changed clear KPDFPages
if ( generator && generator->reparseConfig() )
{
- // tqinvalidate pixmaps
+ // invalidate pixmaps
TQValueVector<KPDFPage*>::iterator it = pages_vector.begin(), end = pages_vector.end();
for ( ; it != end; ++it )
(*it)->deletePixmapsAndRects();
@@ -712,7 +712,7 @@ bool KPDFDocument::searchText( int searchID, const TQString & text, bool fromSta
}
}
- // reset cursor to previous tqshape
+ // reset cursor to previous shape
TQApplication::restoreOverrideCursor();
// send page lists if found anything new
@@ -764,7 +764,7 @@ bool KPDFDocument::searchText( int searchID, const TQString & text, bool fromSta
}
}
- // reset cursor to previous tqshape
+ // reset cursor to previous shape
TQApplication::restoreOverrideCursor();
// if a match has been found..
@@ -793,7 +793,7 @@ bool KPDFDocument::searchText( int searchID, const TQString & text, bool fromSta
}
}
else if ( !noDialogs )
- KMessageBox::information( widget(), i18n("No matches found for '%1'.").tqarg( text ) );
+ KMessageBox::information( widget(), i18n("No matches found for '%1'.").arg( text ) );
}
// 3. PREVMATCH //TODO
else if ( type == PrevMatch )
@@ -865,7 +865,7 @@ bool KPDFDocument::searchText( int searchID, const TQString & text, bool fromSta
}
}
- // reset cursor to previous tqshape
+ // reset cursor to previous shape
TQApplication::restoreOverrideCursor();
// send page lists to update observers (since some filter on bookmarks)
@@ -1016,7 +1016,7 @@ void KPDFDocument::processLink( const KPDFLink * link )
KRun::run( *ptr, lst );
}
else
- KMessageBox::information( widget(), i18n( "No application found for opening file of mimetype %1." ).tqarg( mime->name() ) );
+ KMessageBox::information( widget(), i18n( "No application found for opening file of mimetype %1." ).arg( mime->name() ) );
} break;
case KPDFLink::Action: {
@@ -1067,7 +1067,7 @@ void KPDFDocument::processLink( const KPDFLink * link )
case KPDFLink::Browse: {
const KPDFLinkBrowse * browse = static_cast< const KPDFLinkBrowse * >( link );
// if the url is a mailto one, invoke mailer
- if ( browse->url().tqstartsWith( "mailto:", false ) )
+ if ( browse->url().startsWith( "mailto:", false ) )
kapp->invokeMailer( browse->url() );
else
{
diff --git a/kpdf/core/generator_pdf/generator_pdf.cpp b/kpdf/core/generator_pdf/generator_pdf.cpp
index 6550a543..65e3a55a 100644
--- a/kpdf/core/generator_pdf/generator_pdf.cpp
+++ b/kpdf/core/generator_pdf/generator_pdf.cpp
@@ -209,7 +209,7 @@ const DocumentInfo * PDFGenerator::generateDocumentInfo()
if ( pdfdoc )
{
docInfo.set( "format", i18n( "PDF v. <version>", "PDF v. %1" )
- .tqarg( TQString::number( pdfdoc->getPDFVersion() ) ), i18n( "Format" ) );
+ .arg( TQString::number( pdfdoc->getPDFVersion() ) ), i18n( "Format" ) );
docInfo.set( "encryption", pdfdoc->isEncrypted() ? i18n( "Encrypted" ) : i18n( "Unencrypted" ),
i18n("Security") );
docInfo.set( "optimization", pdfdoc->isLinearized() ? i18n( "Yes" ) : i18n( "No" ),
@@ -457,7 +457,7 @@ bool PDFGenerator::print( KPrinter& printer )
{
pstitle = m_document->currentDocument().fileName( false );
}
- // this looks non-tqunicode-safe and it is. anything other than ASCII is not specified
+ // this looks non-unicode-safe and it is. anything other than ASCII is not specified
// and some printers actually stop printing when they encounter non-ASCII characters in the
// Postscript %%Title tag
TQCString pstitle8Bit = pstitle.latin1();
@@ -528,14 +528,14 @@ static GString *TQStringToGString(const TQString &s) {
int len = s.length();
char *cstring = (char *)gmallocn(s.length(), sizeof(char));
for (int i = 0; i < len; ++i)
- cstring[i] = s.tqat(i).tqunicode();
+ cstring[i] = s.at(i).unicode();
return new GString(cstring, len);
}
-static TQString tqunicodeToTQString(Unicode* u, int len) {
+static TQString unicodeToTQString(Unicode* u, int len) {
TQString ret;
ret.setLength(len);
- TQChar* qch = (TQChar*) ret.tqunicode();
+ TQChar* qch = (TQChar*) ret.unicode();
for (;len;--len)
*qch++ = (TQChar) *u++;
return ret;
@@ -568,7 +568,7 @@ static TQString UnicodeParsedString(GString *s1) {
u = s1->getChar(i) & 0xff;
++i;
}
- result += tqunicodeToTQString( &u, 1 );
+ result += unicodeToTQString( &u, 1 );
}
return result;
}
@@ -868,7 +868,7 @@ void PDFGenerator::addSynopsisChildren( TQDomNode * parent, GList * items )
TQString name;
Unicode * uniChar = outlineItem->getTitle();
int titleLength = outlineItem->getTitleLength();
- name = tqunicodeToTQString(uniChar, titleLength);
+ name = unicodeToTQString(uniChar, titleLength);
if ( name.isEmpty() )
continue;
TQDomElement item = docSyn.createElement( name );
@@ -909,11 +909,11 @@ void PDFGenerator::addSynopsisChildren( TQDomNode * parent, GList * items )
item.setAttribute( "Open", TQVariant( (bool)outlineItem->isOpen() ).toString() );
- // 3. recursively descend over tqchildren
+ // 3. recursively descend over children
outlineItem->open();
- GList * tqchildren = outlineItem->getKids();
- if ( tqchildren )
- addSynopsisChildren( &item, tqchildren );
+ GList * children = outlineItem->getKids();
+ if ( children )
+ addSynopsisChildren( &item, children );
}
}
@@ -1017,10 +1017,10 @@ void PDFGenerator::addTransition( int pageNumber, KPDFPage * page )
switch ( pdfTransition->getAlignment() ) {
case PageTransition::Horizontal:
- transition->tqsetAlignment( KPDFPageTransition::Horizontal );
+ transition->setAlignment( KPDFPageTransition::Horizontal );
break;
case PageTransition::Vertical:
- transition->tqsetAlignment( KPDFPageTransition::Vertical );
+ transition->setAlignment( KPDFPageTransition::Vertical );
break;
}
diff --git a/kpdf/core/link.cpp b/kpdf/core/link.cpp
index a872ba60..fd4aa141 100644
--- a/kpdf/core/link.cpp
+++ b/kpdf/core/link.cpp
@@ -18,12 +18,12 @@ KPDFLink::~KPDFLink()
TQString KPDFLinkGoto::linkTip() const
{
- return m_extFileName.isEmpty() ? ( m_vp.pageNumber != -1 ? i18n( "Go to page %1" ).tqarg( m_vp.pageNumber + 1 ) : TQString() ) : i18n("Open external file");
+ return m_extFileName.isEmpty() ? ( m_vp.pageNumber != -1 ? i18n( "Go to page %1" ).arg( m_vp.pageNumber + 1 ) : TQString() ) : i18n("Open external file");
}
TQString KPDFLinkExecute::linkTip() const
{
- return i18n( "Execute '%1'..." ).tqarg( m_fileName );
+ return i18n( "Execute '%1'..." ).arg( m_fileName );
}
TQString KPDFLinkBrowse::linkTip() const
diff --git a/kpdf/core/page.cpp b/kpdf/core/page.cpp
index 269cab2e..cadaacf3 100644
--- a/kpdf/core/page.cpp
+++ b/kpdf/core/page.cpp
@@ -131,11 +131,11 @@ NormalizedRect * KPDFPage::findText( const TQString & text, bool strictCase, Nor
return 0;
// create a xpf's Unicode (unsigned int) array for the given text
- const TQChar * str = text.tqunicode();
+ const TQChar * str = text.unicode();
int len = text.length();
TQMemArray<Unicode> u(len);
for (int i = 0; i < len; ++i)
- u[i] = str[i].tqunicode();
+ u[i] = str[i].unicode();
// find out the direction of search
enum SearchDir { FromTop, NextMatch, PrevMatch } dir = lastRect ? NextMatch : FromTop;
@@ -319,7 +319,7 @@ bool NormalizedRect::intersects( double l, double t, double r, double b ) const
return (l < right) && (r > left) && (t < bottom) && (b > top);
}
-TQRect NormalizedRect::tqgeometry( int xScale, int yScale ) const
+TQRect NormalizedRect::geometry( int xScale, int yScale ) const
{
int l = (int)( left * xScale ),
t = (int)( top * yScale ),
diff --git a/kpdf/core/page.h b/kpdf/core/page.h
index 1ec5add0..2de7aceb 100644
--- a/kpdf/core/page.h
+++ b/kpdf/core/page.h
@@ -36,7 +36,7 @@ class NormalizedRect
bool intersects( const NormalizedRect & normRect ) const;
bool intersects( double l, double t, double r, double b ) const;
- TQRect tqgeometry( int xScale, int yScale ) const;
+ TQRect geometry( int xScale, int yScale ) const;
};
/**
diff --git a/kpdf/core/pagetransition.cpp b/kpdf/core/pagetransition.cpp
index 41d743c6..c43da45a 100644
--- a/kpdf/core/pagetransition.cpp
+++ b/kpdf/core/pagetransition.cpp
@@ -15,7 +15,7 @@
KPDFPageTransition::KPDFPageTransition( Type type )
: m_type( type ),
m_duration( 1 ),
- m_tqalignment(Horizontal ),
+ m_alignment(Horizontal ),
m_direction( Inward ),
m_angle( 0 ),
m_scale( 1.0 ),
diff --git a/kpdf/core/pagetransition.h b/kpdf/core/pagetransition.h
index 25280437..70792355 100644
--- a/kpdf/core/pagetransition.h
+++ b/kpdf/core/pagetransition.h
@@ -51,7 +51,7 @@ class KPDFPageTransition
inline int duration() const { return m_duration; }
// Get dimension in which the transition effect occurs.
- inline Alignment tqalignment() const { return m_tqalignment; }
+ inline Alignment alignment() const { return m_alignment; }
// Get direction of motion of the transition effect.
inline Direction direction() const { return m_direction; }
@@ -67,7 +67,7 @@ class KPDFPageTransition
inline void setType( Type type ) { m_type = type; }
inline void setDuration( int duration ) { m_duration = duration; }
- inline void tqsetAlignment( Alignment tqalignment ) { m_tqalignment = tqalignment; }
+ inline void setAlignment( Alignment alignment ) { m_alignment = alignment; }
inline void setDirection( Direction direction ) { m_direction = direction; }
inline void setAngle( int angle ) { m_angle = angle; }
inline void setScale( double scale ) { m_scale = scale; }
@@ -76,7 +76,7 @@ class KPDFPageTransition
private:
Type m_type;
int m_duration;
- Alignment m_tqalignment;
+ Alignment m_alignment;
Direction m_direction;
int m_angle;
double m_scale;
diff --git a/kpdf/error.cpp b/kpdf/error.cpp
index ca62437f..00d3581e 100644
--- a/kpdf/error.cpp
+++ b/kpdf/error.cpp
@@ -32,7 +32,7 @@ void CDECL error(int pos, char *msg, ...) {
return;
}
if (pos >= 0) {
- emsg = TQString("Error (%1): ").tqarg(pos);
+ emsg = TQString("Error (%1): ").arg(pos);
} else {
emsg = "Error: ";
}
diff --git a/kpdf/part.cpp b/kpdf/part.cpp
index eec5e95b..2afd73b5 100644
--- a/kpdf/part.cpp
+++ b/kpdf/part.cpp
@@ -25,7 +25,7 @@
#include <tqcheckbox.h>
#include <tqsplitter.h>
#include <tqpainter.h>
-#include <tqlayout.h>
+#include <layout.h>
#include <tqlabel.h>
#include <tqvbox.h>
#include <tqtoolbox.h>
@@ -80,12 +80,12 @@ class PDFOptionsPage : public KPrintDialogPage
PDFOptionsPage()
{
setTitle( i18n( "PDF Options" ) );
- TQVBoxLayout *tqlayout = new TQVBoxLayout(this);
+ TQVBoxLayout *layout = new TQVBoxLayout(this);
m_forceRaster = new TQCheckBox(i18n("Force rasterization"), this);
TQToolTip::add(m_forceRaster, i18n("Rasterize into an image before printing"));
TQWhatsThis::add(m_forceRaster, i18n("Forces the rasterization of each page into an image before printing it. This usually gives somewhat worse results, but is useful when printing documents that appear to print incorrectly."));
- tqlayout->addWidget(m_forceRaster);
- tqlayout->addStretch(1);
+ layout->addWidget(m_forceRaster);
+ layout->addStretch(1);
}
void getOptions( TQMap<TQString,TQString>& opts, bool incldef = false )
@@ -151,7 +151,7 @@ Part::Part(TQWidget *parentWidget, const char *widgetName,
connect( m_document, TQT_SIGNAL( openURL(const KURL &) ), this, TQT_SLOT( openURLFromDocument(const KURL &) ) );
connect( m_document, TQT_SIGNAL( close() ), this, TQT_SLOT( close() ) );
- if (parent && parent->tqmetaObject()->slotNames(true).contains("slotQuit()"))
+ if (parent && parent->metaObject()->slotNames(true).contains("slotQuit()"))
connect( m_document, TQT_SIGNAL( quit() ), parent, TQT_SLOT( slotQuit() ) );
else
connect( m_document, TQT_SIGNAL( quit() ), this, TQT_SLOT( cannotQuit() ) );
@@ -186,7 +186,7 @@ Part::Part(TQWidget *parentWidget, const char *widgetName,
int index;
// [left toolbox: Table of Contents] | []
- // dummy wrapper with tqlayout to enable horizontal scroll bars (bug: 147233)
+ // dummy wrapper with layout to enable horizontal scroll bars (bug: 147233)
TQWidget *tocWrapper = new TQWidget(m_toolBox);
TQVBoxLayout *tocWrapperLayout = new TQVBoxLayout(tocWrapper);
m_tocFrame = new TOC( tocWrapper, m_document );
@@ -297,7 +297,7 @@ Part::Part(TQWidget *parentWidget, const char *widgetName,
m_showPresentation = new KAction( i18n("P&resentation"), "kpresenter_kpr", "Ctrl+Shift+P", this, TQT_SLOT(slotShowPresentation()), ac, "presentation");
m_showPresentation->setEnabled( false );
- // attach the actions of the tqchildren widgets too
+ // attach the actions of the children widgets too
m_pageView->setupActions( ac );
// apply configuration (both internal settings and GUI configured items)
@@ -510,7 +510,7 @@ bool Part::openURL(const KURL &url)
// these setWindowCaption calls only work for local files
if ( !b )
{
- KMessageBox::error( widget(), i18n("Could not open %1").tqarg( url.prettyURL() ) );
+ KMessageBox::error( widget(), i18n("Could not open %1").arg( url.prettyURL() ) );
emit setWindowCaption("");
}
else
@@ -806,17 +806,17 @@ void Part::slotSaveFileAs()
{
if (saveURL == url())
{
- KMessageBox::information( widget(), i18n("You are trying to overwrite \"%1\" with itself. This is not allowed. Please save it in another location.").tqarg(saveURL.filename()) );
+ KMessageBox::information( widget(), i18n("You are trying to overwrite \"%1\" with itself. This is not allowed. Please save it in another location.").arg(saveURL.filename()) );
return;
}
if ( KIO::NetAccess::exists( saveURL, false, widget() ) )
{
- if (KMessageBox::warningContinueCancel( widget(), i18n("A file named \"%1\" already exists. Are you sure you want to overwrite it?").tqarg(saveURL.filename()), TQString(), i18n("Overwrite")) != KMessageBox::Continue)
+ if (KMessageBox::warningContinueCancel( widget(), i18n("A file named \"%1\" already exists. Are you sure you want to overwrite it?").arg(saveURL.filename()), TQString(), i18n("Overwrite")) != KMessageBox::Continue)
return;
}
if ( !KIO::NetAccess::file_copy( m_file, saveURL, -1, true ) )
- KMessageBox::information( 0, i18n("File could not be saved in '%1'. Try to save it to another location.").tqarg( saveURL.prettyURL() ) );
+ KMessageBox::information( 0, i18n("File could not be saved in '%1'. Try to save it to another location.").arg( saveURL.prettyURL() ) );
}
}
@@ -939,7 +939,7 @@ void Part::slotShowMenu(const KPDFPage *page, const TQPoint &point)
KPopupMenu *popup = new KPopupMenu( widget(), "rmb popup" );
if (page)
{
- popup->insertTitle( i18n( "Page %1" ).tqarg( page->number() + 1 ) );
+ popup->insertTitle( i18n( "Page %1" ).arg( page->number() + 1 ) );
if ( page->hasBookmark() )
popup->insertItem( SmallIcon("bookmark"), i18n("Remove Bookmark"), 1 );
else
diff --git a/kpdf/ui/minibar.cpp b/kpdf/ui/minibar.cpp
index fed4602e..65a213d8 100644
--- a/kpdf/ui/minibar.cpp
+++ b/kpdf/ui/minibar.cpp
@@ -13,7 +13,7 @@
#include <tqpushbutton.h>
#include <tqlabel.h>
#include <tqlineedit.h>
-#include <tqlayout.h>
+#include <layout.h>
#include <tqvalidator.h>
#include <tqpainter.h>
#include <kiconloader.h>
@@ -87,7 +87,7 @@ MiniBar::MiniBar( TQWidget * parent, KPDFDocument * document )
TQSpacerItem * spacerL = new TQSpacerItem( 20, 10, TQSizePolicy::Expanding );
horLayout->addItem( spacerL );
- // central 2r by 3c grid tqlayout that contains all components
+ // central 2r by 3c grid layout that contains all components
TQGridLayout * gridLayout = new TQGridLayout( 0, 3,5, 2,1 );
// top spacer 6x6 px
// TQSpacerItem * spacerTop = new TQSpacerItem( 6, 6, TQSizePolicy::Fixed, TQSizePolicy::Fixed );
@@ -198,7 +198,7 @@ void MiniBar::notifyViewportChanged( bool /*smoothMove*/ )
void MiniBar::resizeEvent( TQResizeEvent * e )
{
// auto-hide 'prev' and 'next' buttons if not enough space
- const TQSize & myHint = tqminimumSizeHint();
+ const TQSize & myHint = minimumSizeHint();
bool shown = m_prevButton->isVisible() && m_nextButton->isVisible();
if ( shown && e->size().width() < myHint.width() )
{
@@ -208,7 +208,7 @@ void MiniBar::resizeEvent( TQResizeEvent * e )
}
else if ( !shown )
{
- int histeresis = m_prevButton->tqsizeHint().width() * 2 + 2;
+ int histeresis = m_prevButton->sizeHint().width() * 2 + 2;
if ( e->size().width() > (myHint.width() + histeresis) )
{
m_prevButton->show();
@@ -308,17 +308,17 @@ void ProgressWidget::paintEvent( TQPaintEvent * e )
// paint rects and a separator line
TQPainter p( this );
if ( cRect.isValid() )
- p.fillRect( cRect, tqpalette().active().highlightedText() );
+ p.fillRect( cRect, palette().active().highlightedText() );
if ( fRect.isValid() )
- p.fillRect( fRect, tqpalette().active().highlight() );
+ p.fillRect( fRect, palette().active().highlight() );
if ( l && l != w )
{
- p.setPen( tqpalette().active().highlight().dark( 120 ) );
+ p.setPen( palette().active().highlight().dark( 120 ) );
int delta = TQApplication::reverseLayout() ? w - l : l;
p.drawLine( delta, 0, delta, h );
}
// draw a frame-like outline
- //p.setPen( tqpalette().active().mid() );
+ //p.setPen( palette().active().mid() );
//p.drawRect( 0,0, w, h );
}
@@ -337,7 +337,7 @@ PagesEdit::PagesEdit( MiniBar * parent )
setValidator( m_validator );
// customize text properties
- tqsetAlignment( TQt::AlignCenter );
+ setAlignment( TQt::AlignCenter );
setMaxLength( 4 );
}
@@ -372,7 +372,7 @@ void PagesEdit::focusOutEvent( TQFocusEvent * e )
{
// change background color to a dark tone
setLineWidth( 1 );
- setPaletteBackgroundColor( tqpalette().active().background().light( 105 ) );
+ setPaletteBackgroundColor( palette().active().background().light( 105 ) );
// restore text
TQLineEdit::setText( backString );
// call default handler
@@ -428,7 +428,7 @@ void HoverButton::paintEvent( TQPaintEvent * e )
else
{
TQPainter p( this );
- p.fillRect(e->rect(), parentWidget() ? parentWidget()->tqpalette().brush(TQPalette::Active, TQColorGroup::Background) : paletteBackgroundColor());
+ p.fillRect(e->rect(), parentWidget() ? parentWidget()->palette().brush(TQPalette::Active, TQColorGroup::Background) : paletteBackgroundColor());
drawButtonLabel( &p );
}
}
diff --git a/kpdf/ui/pagepainter.cpp b/kpdf/ui/pagepainter.cpp
index 21e9c37f..a4644c16 100644
--- a/kpdf/ui/pagepainter.cpp
+++ b/kpdf/ui/pagepainter.cpp
@@ -139,7 +139,7 @@ void PagePainter::paintPageOnPainter( const KPDFPage * page, int id, int flags,
{
case KpdfSettings::EnumRenderMode::Inverted:
// Invert image pixels using TQImage internal function
- backImage.tqinvertPixels(false);
+ backImage.invertPixels(false);
break;
case KpdfSettings::EnumRenderMode::Recolor:
// Recolor image using KImageEffect::flatten with dither:0
@@ -178,7 +178,7 @@ void PagePainter::paintPageOnPainter( const KPDFPage * page, int id, int flags,
for ( ; hIt != hEnd; ++hIt )
{
HighlightRect * r = *hIt;
- TQRect highlightRect = r->tqgeometry( width, height );
+ TQRect highlightRect = r->geometry( width, height );
if ( highlightRect.isValid() && highlightRect.intersects( limits ) )
{
// find out the rect to highlight on pixmap
@@ -213,7 +213,7 @@ void PagePainter::paintPageOnPainter( const KPDFPage * page, int id, int flags,
// 3. visually enchance links and images if requested
if ( enhanceLinks || enhanceImages )
{
- TQColor normalColor = TQApplication::tqpalette().active().highlight();
+ TQColor normalColor = TQApplication::palette().active().highlight();
TQColor lightColor = normalColor.light( 140 );
// enlarging limits for intersection is like growing the 'rectGeometry' below
TQRect limitsEnlarged = limits;
@@ -226,7 +226,7 @@ void PagePainter::paintPageOnPainter( const KPDFPage * page, int id, int flags,
if ( (enhanceLinks && rect->objectType() == ObjectRect::Link) ||
(enhanceImages && rect->objectType() == ObjectRect::Image) )
{
- TQRect rectGeometry = rect->tqgeometry( width, height );
+ TQRect rectGeometry = rect->geometry( width, height );
if ( rectGeometry.intersects( limitsEnlarged ) )
{
// expand rect and draw inner border
diff --git a/kpdf/ui/presentationwidget.cpp b/kpdf/ui/presentationwidget.cpp
index 6e8f52c2..74800e88 100644
--- a/kpdf/ui/presentationwidget.cpp
+++ b/kpdf/ui/presentationwidget.cpp
@@ -43,12 +43,12 @@
#define ENABLE_PROGRESS_OVERLAY
-// a frame contains a pointer to the page object, its tqgeometry and the
+// a frame contains a pointer to the page object, its geometry and the
// transition effect to the next frame
struct PresentationFrame
{
const KPDFPage * page;
- TQRect tqgeometry;
+ TQRect geometry;
};
@@ -56,7 +56,7 @@ PresentationWidget::PresentationWidget( TQWidget * parent, KPDFDocument * doc )
: TQDialog( parent, "presentationWidget", true, WDestructiveClose | WStyle_NoBorder),
m_pressedLink( 0 ), m_handCursor( false ), m_document( doc ), m_frameIndex( -1 )
{
- // set look and tqgeometry
+ // set look and geometry
setBackgroundMode( TQt::NoBackground );
m_width = -1;
@@ -124,7 +124,7 @@ void PresentationWidget::notifySetup( const TQValueVector< KPDFPage * > & pageSe
{
PresentationFrame * frame = new PresentationFrame();
frame->page = *setIt;
- // calculate frame tqgeometry keeping constant aspect ratio
+ // calculate frame geometry keeping constant aspect ratio
float pageRatio = frame->page->ratio();
int pageWidth = m_width,
pageHeight = m_height;
@@ -132,7 +132,7 @@ void PresentationWidget::notifySetup( const TQValueVector< KPDFPage * > & pageSe
pageWidth = (int)( (float)pageHeight / pageRatio );
else
pageHeight = (int)( (float)pageWidth * pageRatio );
- frame->tqgeometry.setRect( (m_width - pageWidth) / 2,
+ frame->geometry.setRect( (m_width - pageWidth) / 2,
(m_height - pageHeight) / 2,
pageWidth, pageHeight );
// add the frame to the vector
@@ -145,11 +145,11 @@ void PresentationWidget::notifySetup( const TQValueVector< KPDFPage * > & pageSe
if ( info )
{
if ( !info->get( "title" ).isNull() )
- m_metaStrings += i18n( "Title: %1" ).tqarg( info->get( "title" ) );
+ m_metaStrings += i18n( "Title: %1" ).arg( info->get( "title" ) );
if ( !info->get( "author" ).isNull() )
- m_metaStrings += i18n( "Author: %1" ).tqarg( info->get( "author" ) );
+ m_metaStrings += i18n( "Author: %1" ).arg( info->get( "author" ) );
}
- m_metaStrings += i18n( "Pages: %1" ).tqarg( m_document->pages() );
+ m_metaStrings += i18n( "Pages: %1" ).arg( m_document->pages() );
m_metaStrings += i18n( "Click to begin" );
}
@@ -287,9 +287,9 @@ void PresentationWidget::mouseMoveEvent( TQMouseEvent * e )
else
{
// show the bar if reaching top 2 pixels
- if ( e->y() <= (tqgeometry().top() + 1) )
+ if ( e->y() <= (geometry().top() + 1) )
m_topBar->show();
- // handle "dragging the wheel" if clicking on its tqgeometry
+ // handle "dragging the wheel" if clicking on its geometry
else if ( e->state() == Qt::LeftButton && m_overlayGeometry.contains( e->pos() ) )
overlayClick( e->pos() );
}
@@ -314,7 +314,7 @@ void PresentationWidget::paintEvent( TQPaintEvent * pe )
m_topBar->alignItemRight( 1 );
m_topBar->hide();
// change topbar background color
- TQPalette p = m_topBar->tqpalette();
+ TQPalette p = m_topBar->palette();
p.setColor( TQPalette::Active, TQColorGroup::Button, TQt::gray );
p.setColor( TQPalette::Active, TQColorGroup::Background, TQt::darkGray );
m_topBar->setPalette( p );
@@ -330,12 +330,12 @@ void PresentationWidget::paintEvent( TQPaintEvent * pe )
}
// check painting rect consistancy
- TQRect r = pe->rect().intersect( tqgeometry() );
+ TQRect r = pe->rect().intersect( geometry() );
if ( r.isNull() || m_lastRenderedPixmap.isNull() )
return;
// blit the pixmap to the screen
- TQMemArray<TQRect> allRects = TQRegion(pe->region()).tqrects();
+ TQMemArray<TQRect> allRects = TQRegion(pe->region()).rects();
uint numRects = allRects.count();
for ( uint i = 0; i < numRects; i++ )
{
@@ -370,18 +370,18 @@ void PresentationWidget::paintEvent( TQPaintEvent * pe )
// </widget events>
-const KPDFLink * PresentationWidget::getLink( int x, int y, TQRect * tqgeometry ) const
+const KPDFLink * PresentationWidget::getLink( int x, int y, TQRect * geometry ) const
{
// no links on invalid pages
- if ( tqgeometry && !tqgeometry->isNull() )
- tqgeometry->setRect( 0, 0, -1, -1 );
+ if ( geometry && !geometry->isNull() )
+ geometry->setRect( 0, 0, -1, -1 );
if ( m_frameIndex < 0 || m_frameIndex >= (int)m_frames.size() )
return 0;
- // get frame, page and tqgeometry
+ // get frame, page and geometry
const PresentationFrame * frame = m_frames[ m_frameIndex ];
const KPDFPage * page = frame->page;
- const TQRect & frameGeometry = frame->tqgeometry;
+ const TQRect & frameGeometry = frame->geometry;
// compute normalized x and y
double nx = (double)(x - frameGeometry.left()) / (double)frameGeometry.width();
@@ -396,11 +396,11 @@ const KPDFLink * PresentationWidget::getLink( int x, int y, TQRect * tqgeometry
if ( !object )
return 0;
- // compute link tqgeometry if destination rect present
- if ( tqgeometry )
+ // compute link geometry if destination rect present
+ if ( geometry )
{
- *tqgeometry = object->tqgeometry( frameGeometry.width(), frameGeometry.height() );
- tqgeometry->moveBy( frameGeometry.left(), frameGeometry.top() );
+ *geometry = object->geometry( frameGeometry.width(), frameGeometry.height() );
+ geometry->moveBy( frameGeometry.left(), frameGeometry.top() );
}
// return the link pointer
@@ -416,7 +416,7 @@ void PresentationWidget::testCursorOnLink( int x, int y )
// only react on changes (in/out from a link)
if ( (link && !m_handCursor) || (!link && m_handCursor) )
{
- // change cursor tqshape
+ // change cursor shape
m_handCursor = link != 0;
setCursor( m_handCursor ? KCursor::handCursor() : KCursor::arrowCursor());
@@ -451,8 +451,8 @@ void PresentationWidget::changePage( int newPage )
// check if pixmap exists or else request it
m_frameIndex = newPage;
PresentationFrame * frame = m_frames[ m_frameIndex ];
- int pixW = frame->tqgeometry.width();
- int pixH = frame->tqgeometry.height();
+ int pixW = frame->geometry.width();
+ int pixH = frame->geometry.height();
// if pixmap not inside the KPDFPage we request it and wait for
// notifyPixmapChanged call or else we can proceed to pixmap generation
@@ -470,16 +470,16 @@ void PresentationWidget::changePage( int newPage )
if (newPage + 1 < (int)m_document->pages())
{
PresentationFrame *nextFrame = m_frames[ newPage + 1 ];
- pixW = nextFrame->tqgeometry.width();
- pixH = nextFrame->tqgeometry.height();
+ pixW = nextFrame->geometry.width();
+ pixH = nextFrame->geometry.height();
if ( !nextFrame->page->hasPixmap( PRESENTATION_ID, pixW, pixH ) )
requests.push_back( new PixmapRequest( PRESENTATION_ID, newPage + 1, pixW, pixH, PRESENTATION_PRELOAD_PRIO, true ) );
}
if (newPage - 1 >= 0)
{
PresentationFrame *prevFrame = m_frames[ newPage - 1 ];
- pixW = prevFrame->tqgeometry.width();
- pixH = prevFrame->tqgeometry.height();
+ pixW = prevFrame->geometry.width();
+ pixH = prevFrame->geometry.height();
if ( !prevFrame->page->hasPixmap( PRESENTATION_ID, pixW, pixH ) )
requests.push_back( new PixmapRequest( PRESENTATION_ID, newPage - 1, pixW, pixH, PRESENTATION_PRELOAD_PRIO, true ) );
}
@@ -595,7 +595,7 @@ void PresentationWidget::generateContentsPage( int pageNum, TQPainter & p )
PresentationFrame * frame = m_frames[ pageNum ];
// translate painter and contents rect
- TQRect geom( frame->tqgeometry );
+ TQRect geom( frame->geometry );
p.translate( geom.left(), geom.top() );
geom.moveBy( -geom.left(), -geom.top() );
@@ -605,11 +605,11 @@ void PresentationWidget::generateContentsPage( int pageNum, TQPainter & p )
&p, geom, geom.width(), geom.height() );
// restore painter
- p.translate( -frame->tqgeometry.left(), -frame->tqgeometry.top() );
+ p.translate( -frame->geometry.left(), -frame->geometry.top() );
// fill unpainted areas with background color
TQRegion unpainted( TQRect( 0, 0, m_width, m_height ) );
- TQMemArray<TQRect> rects = TQRegion(unpainted.subtract( frame->tqgeometry )).tqrects();
+ TQMemArray<TQRect> rects = TQRegion(unpainted.subtract( frame->geometry )).rects();
for ( uint i = 0; i < rects.count(); i++ )
{
const TQRect & r = rects[i];
@@ -622,7 +622,7 @@ inline int qt_div255(int x) { return (x + (x>>8) + 0x80) >> 8; }
void PresentationWidget::generateOverlay()
{
#ifdef ENABLE_PROGRESS_OVERLAY
- // calculate overlay tqgeometry and resize pixmap if needed
+ // calculate overlay geometry and resize pixmap if needed
int side = m_width / 16;
m_overlayGeometry.setRect( m_width - side - 4, 4, side, side );
if ( m_lastRenderedOverlay.width() != side )
@@ -690,9 +690,9 @@ void PresentationWidget::generateOverlay()
// generate a 2 colors pixmap using mixing shadow (made with highlight color)
// and image (made with highlightedText color)
- TQColor color = tqpalette().active().highlightedText();
+ TQColor color = palette().active().highlightedText();
int red = color.red(), green = color.green(), blue = color.blue();
- color = tqpalette().active().highlight();
+ color = palette().active().highlight();
int sRed = color.red(), sGreen = color.green(), sBlue = color.blue();
// pointers
unsigned int * data = (unsigned int *)image.bits(),
@@ -725,7 +725,7 @@ void PresentationWidget::generateOverlay()
m_lastRenderedOverlay.convertFromImage( image );
// start the autohide timer
- tqrepaint( m_overlayGeometry, false /*clear*/ ); // toggle with next line
+ repaint( m_overlayGeometry, false /*clear*/ ); // toggle with next line
//update( m_overlayGeometry );
m_overlayHideTimer->start( 2500, true );
#endif
@@ -837,14 +837,14 @@ const KPDFPageTransition PresentationWidget::defaultTransition( int type ) const
case KpdfSettings::EnumSlidesTransition::BlindsHorizontal:
{
KPDFPageTransition transition( KPDFPageTransition::Blinds );
- transition.tqsetAlignment( KPDFPageTransition::Horizontal );
+ transition.setAlignment( KPDFPageTransition::Horizontal );
return transition;
break;
}
case KpdfSettings::EnumSlidesTransition::BlindsVertical:
{
KPDFPageTransition transition( KPDFPageTransition::Blinds );
- transition.tqsetAlignment( KPDFPageTransition::Vertical );
+ transition.setAlignment( KPDFPageTransition::Vertical );
return transition;
break;
}
@@ -896,7 +896,7 @@ const KPDFPageTransition PresentationWidget::defaultTransition( int type ) const
case KpdfSettings::EnumSlidesTransition::SplitHorizontalIn:
{
KPDFPageTransition transition( KPDFPageTransition::Split );
- transition.tqsetAlignment( KPDFPageTransition::Horizontal );
+ transition.setAlignment( KPDFPageTransition::Horizontal );
transition.setDirection( KPDFPageTransition::Inward );
return transition;
break;
@@ -904,7 +904,7 @@ const KPDFPageTransition PresentationWidget::defaultTransition( int type ) const
case KpdfSettings::EnumSlidesTransition::SplitHorizontalOut:
{
KPDFPageTransition transition( KPDFPageTransition::Split );
- transition.tqsetAlignment( KPDFPageTransition::Horizontal );
+ transition.setAlignment( KPDFPageTransition::Horizontal );
transition.setDirection( KPDFPageTransition::Outward );
return transition;
break;
@@ -912,7 +912,7 @@ const KPDFPageTransition PresentationWidget::defaultTransition( int type ) const
case KpdfSettings::EnumSlidesTransition::SplitVerticalIn:
{
KPDFPageTransition transition( KPDFPageTransition::Split );
- transition.tqsetAlignment( KPDFPageTransition::Vertical );
+ transition.setAlignment( KPDFPageTransition::Vertical );
transition.setDirection( KPDFPageTransition::Inward );
return transition;
break;
@@ -920,7 +920,7 @@ const KPDFPageTransition PresentationWidget::defaultTransition( int type ) const
case KpdfSettings::EnumSlidesTransition::SplitVerticalOut:
{
KPDFPageTransition transition( KPDFPageTransition::Split );
- transition.tqsetAlignment( KPDFPageTransition::Vertical );
+ transition.setAlignment( KPDFPageTransition::Vertical );
transition.setDirection( KPDFPageTransition::Outward );
return transition;
break;
@@ -963,7 +963,7 @@ const KPDFPageTransition PresentationWidget::defaultTransition( int type ) const
/** ONLY the TRANSITIONS GENERATION function from here on **/
void PresentationWidget::initTransition( const KPDFPageTransition *transition )
{
- // if it's just a 'replace' transition, tqrepaint the screen
+ // if it's just a 'replace' transition, repaint the screen
if ( transition->type() == KPDFPageTransition::Replace )
{
update();
@@ -971,7 +971,7 @@ void PresentationWidget::initTransition( const KPDFPageTransition *transition )
}
const bool isInward = transition->direction() == KPDFPageTransition::Inward;
- const bool isHorizontal = transition->tqalignment() == KPDFPageTransition::Horizontal;
+ const bool isHorizontal = transition->alignment() == KPDFPageTransition::Horizontal;
const float totalTime = transition->duration();
m_transitionRects.clear();
diff --git a/kpdf/ui/presentationwidget.h b/kpdf/ui/presentationwidget.h
index 26db0836..000bfeaa 100644
--- a/kpdf/ui/presentationwidget.h
+++ b/kpdf/ui/presentationwidget.h
@@ -60,7 +60,7 @@ class PresentationWidget : public TQDialog, public DocumentObserver
void paintEvent( TQPaintEvent * e );
private:
- const KPDFLink * getLink( int x, int y, TQRect * tqgeometry = 0 ) const;
+ const KPDFLink * getLink( int x, int y, TQRect * geometry = 0 ) const;
void testCursorOnLink( int x, int y );
void overlayClick( const TQPoint & position );
void changePage( int newPage );
diff --git a/kpdf/ui/propertiesdialog.cpp b/kpdf/ui/propertiesdialog.cpp
index d9cee932..d3d0af60 100644
--- a/kpdf/ui/propertiesdialog.cpp
+++ b/kpdf/ui/propertiesdialog.cpp
@@ -8,7 +8,7 @@
***************************************************************************/
// qt/kde includes
-#include <tqlayout.h>
+#include <layout.h>
#include <tqlabel.h>
#include <klistview.h>
#include <klocale.h>
@@ -24,18 +24,18 @@ PropertiesDialog::PropertiesDialog(TQWidget *parent, KPDFDocument *doc)
{
// Properties
TQFrame *page = addPage(i18n("Properties"));
- TQGridLayout *tqlayout = new TQGridLayout( page, 2, 2, marginHint(), spacingHint() );
+ TQGridLayout *layout = new TQGridLayout( page, 2, 2, marginHint(), spacingHint() );
// get document info, if not present display blank data and a warning
const DocumentInfo * info = doc->documentInfo();
if ( !info ) {
- tqlayout->addWidget( new TQLabel( i18n( "No document opened." ), page ), 0, 0 );
+ layout->addWidget( new TQLabel( i18n( "No document opened." ), page ), 0, 0 );
return;
}
// mime name based on mimetype id
TQString mimeName = info->get( "mimeType" ).section( '/', -1 ).upper();
- setCaption( i18n("%1 Properties").tqarg( mimeName ) );
+ setCaption( i18n("%1 Properties").arg( mimeName ) );
TQDomElement docElement = info->documentElement();
@@ -49,11 +49,11 @@ PropertiesDialog::PropertiesDialog(TQWidget *parent, KPDFDocument *doc)
if ( titleString.isEmpty() || valueString.isEmpty() )
continue;
- // create labels and tqlayout them
- TQLabel *key = new TQLabel( i18n( "%1:" ).tqarg( titleString ), page );
+ // create labels and layout them
+ TQLabel *key = new TQLabel( i18n( "%1:" ).arg( titleString ), page );
TQLabel *value = new KSqueezedTextLabel( valueString, page );
- tqlayout->addWidget( key, row, 0, AlignRight );
- tqlayout->addWidget( value, row, 1 );
+ layout->addWidget( key, row, 0, AlignRight );
+ layout->addWidget( value, row, 1 );
row++;
// refine maximum width of 'value' labels
@@ -66,8 +66,8 @@ PropertiesDialog::PropertiesDialog(TQWidget *parent, KPDFDocument *doc)
TQLabel *key = new TQLabel( i18n( "Pages:" ), page );
TQLabel *value = new TQLabel( TQString::number( doc->pages() ), page );
- tqlayout->addWidget( key, row, 0 );
- tqlayout->addWidget( value, row, 1 );
+ layout->addWidget( key, row, 0 );
+ layout->addWidget( value, row, 1 );
}
// Fonts
@@ -82,10 +82,10 @@ PropertiesDialog::PropertiesDialog(TQWidget *parent, KPDFDocument *doc)
}
// current width: left column + right column + dialog borders
- int width = tqlayout->tqminimumSize().width() + valMaxWidth + marginHint() + spacingHint() + marginHint() + 30;
+ int width = layout->minimumSize().width() + valMaxWidth + marginHint() + spacingHint() + marginHint() + 30;
if (page2Layout)
{
- width = TQMAX( width, page2Layout->tqsizeHint().width() + marginHint() + spacingHint() + 31 );
+ width = TQMAX( width, page2Layout->sizeHint().width() + marginHint() + spacingHint() + 31 );
}
// stay inside the 2/3 of the screen width
TQRect screenContainer = KGlobalSettings::desktopGeometry( this );
diff --git a/kpdf/ui/searchwidget.cpp b/kpdf/ui/searchwidget.cpp
index 7ca3ba49..f21d8b73 100644
--- a/kpdf/ui/searchwidget.cpp
+++ b/kpdf/ui/searchwidget.cpp
@@ -79,10 +79,10 @@ void SearchWidget::clearText()
void SearchWidget::slotTextChanged( const TQString & text )
{
// if 0<length<3 set 'red' text and send a blank string to document
- TQColor color = text.length() > 0 && text.length() < 3 ? TQt::darkRed : tqpalette().active().text();
+ TQColor color = text.length() > 0 && text.length() < 3 ? TQt::darkRed : palette().active().text();
KLineEdit * lineEdit = getLined( LEDIT_ID );
lineEdit->setPaletteForegroundColor( color );
- lineEdit->setPaletteBackgroundColor( tqpalette().active().base() );
+ lineEdit->setPaletteBackgroundColor( palette().active().base() );
m_inputDelayTimer->stop();
m_inputDelayTimer->start(333, true);
}
diff --git a/kpdf/ui/thumbnaillist.cpp b/kpdf/ui/thumbnaillist.cpp
index a41869d6..6c5e2b5f 100644
--- a/kpdf/ui/thumbnaillist.cpp
+++ b/kpdf/ui/thumbnaillist.cpp
@@ -82,7 +82,7 @@ ThumbnailList::ThumbnailList( TQWidget *parent, KPDFDocument *document )
setDragAutoScroll( false );
// set contents background to the 'base' color
- viewport()->setPaletteBackgroundColor( tqpalette().active().base() );
+ viewport()->setPaletteBackgroundColor( palette().active().base() );
setFrameStyle( StyledPanel | Raised );
connect( this, TQT_SIGNAL(contentsMoving(int, int)), this, TQT_SLOT(slotRequestVisiblePixmaps(int, int)) );
@@ -199,7 +199,7 @@ void ThumbnailList::notifyPageChanged( int pageNumber, int /*changedFlags*/ )
//if ( !(changedFlags & DocumentObserver::Pixmap) )
// return;
- // iterate over visible items: if page(pageNumber) is one of them, tqrepaint it
+ // iterate over visible items: if page(pageNumber) is one of them, repaint it
TQValueList<ThumbnailWidget *>::iterator vIt = m_visibleThumbnails.begin(), vEnd = m_visibleThumbnails.end();
for ( ; vIt != vEnd; ++vIt )
if ( (*vIt)->pageNumber() == pageNumber )
@@ -362,7 +362,7 @@ void ThumbnailList::viewportResizeEvent( TQResizeEvent * e )
else if ( e->size().height() <= e->oldSize().height() )
return;
- // tqinvalidate the bookmark overlay
+ // invalidate the bookmark overlay
if ( m_bookmarkOverlay )
{
delete m_bookmarkOverlay;
@@ -495,9 +495,9 @@ void ThumbnailWidget::paintEvent( TQPaintEvent * e )
TQPainter p( this );
// draw the bottom label + highlight mark
- TQColor fillColor = m_selected ? tqpalette().active().highlight() : tqpalette().active().base();
+ TQColor fillColor = m_selected ? palette().active().highlight() : palette().active().base();
p.fillRect( 0, 0, width, height, fillColor );
- p.setPen( m_selected ? tqpalette().active().highlightedText() : tqpalette().active().text() );
+ p.setPen( m_selected ? palette().active().highlightedText() : palette().active().text() );
p.drawText( 0, m_pixmapHeight + m_margin, width, m_labelHeight, TQt::AlignCenter, TQString::number( m_labelNumber ) );
// draw page outline and pixmap
@@ -509,7 +509,7 @@ void ThumbnailWidget::paintEvent( TQPaintEvent * e )
p.setPen( isBookmarked ? TQColor( 0xFF8000 ) : TQt::black );
p.drawRect( m_margin/2 - 1, m_margin/2 - 1, m_pixmapWidth + 2, m_pixmapHeight + 2 );
// draw the clear rect
- p.setPen( isBookmarked ? TQColor( 0x804000 ) : tqpalette().active().base() );
+ p.setPen( isBookmarked ? TQColor( 0x804000 ) : palette().active().base() );
// draw the bottom and right shadow edges
if ( !isBookmarked )
{
diff --git a/kpdf/ui/thumbnaillist.h b/kpdf/ui/thumbnaillist.h
index 549ea20c..fb128045 100644
--- a/kpdf/ui/thumbnaillist.h
+++ b/kpdf/ui/thumbnaillist.h
@@ -102,7 +102,7 @@ class ThumbnailsBox : public TQVBox
{
public:
ThumbnailsBox( TQWidget * parent ) : TQVBox( parent ) {};
- TQSize tqsizeHint() const { return TQSize(); }
+ TQSize sizeHint() const { return TQSize(); }
};
/**
diff --git a/kpdf/ui/pageview.cpp b/kpdf/ui/pageview.cpp
index de5fad0c..157a3655 100644
--- a/kpdf/ui/pageview.cpp
+++ b/kpdf/ui/pageview.cpp
@@ -24,7 +24,7 @@
#include <tqpushbutton.h>
#include <tqtooltip.h>
#include <tqapplication.h>
-#include <tqclipboard.h>
+#include <clipboard.h>
#include <dcopclient.h>
#include <kcursor.h>
#include <kiconloader.h>
@@ -68,7 +68,7 @@ public:
TQValueVector< PageViewItem * > items;
TQValueList< PageViewItem * > visibleItems;
- // view tqlayout (columns and continuous in Settings), zoom and mouse
+ // view layout (columns and continuous in Settings), zoom and mouse
PageView::ZoomMode zoomMode;
float zoomFactor;
int rotation;
@@ -146,8 +146,8 @@ void PageViewTip::maybeTip( const TQPoint &_p )
PageViewItem * pageItem = m_view->pickItemOnPoint( p.x(), p.y() );
if ( pageItem && m_view->d->mouseMode == PageView::MouseNormal )
{
- double nX = (double)(p.x() - pageItem->tqgeometry().left()) / (double)pageItem->width(),
- nY = (double)(p.y() - pageItem->tqgeometry().top()) / (double)pageItem->height();
+ double nX = (double)(p.x() - pageItem->geometry().left()) / (double)pageItem->width(),
+ nY = (double)(p.y() - pageItem->geometry().top()) / (double)pageItem->height();
// if over a ObjectRect (of type Link) change cursor to hand
const ObjectRect * object = pageItem->page()->hasObject( ObjectRect::Link, nX, nY );
@@ -158,8 +158,8 @@ void PageViewTip::maybeTip( const TQPoint &_p )
TQString strtip = link->linkTip();
if ( !strtip.isEmpty() )
{
- TQRect linkRect = object->tqgeometry( pageItem->width(), pageItem->height() );
- linkRect.moveBy( - m_view->contentsX() + pageItem->tqgeometry().left(), - m_view->contentsY() + pageItem->tqgeometry().top() );
+ TQRect linkRect = object->geometry( pageItem->width(), pageItem->height() );
+ linkRect.moveBy( - m_view->contentsX() + pageItem->geometry().left(), - m_view->contentsY() + pageItem->geometry().top() );
tip( linkRect, strtip );
}
}
@@ -337,7 +337,7 @@ void PageView::notifySetup( const TQValueVector< KPDFPage * > & pageSet, bool do
d->items.clear();
d->visibleItems.clear();
- // create tqchildren widgets
+ // create children widgets
TQValueVector< KPDFPage * >::const_iterator setIt = pageSet.begin(), setEnd = pageSet.end();
for ( ; setIt != setEnd; ++setIt )
d->items.push_back( new PageViewItem( *setIt ) );
@@ -392,13 +392,13 @@ void PageView::notifyViewportChanged( bool smoothMove )
return;
}
- // retqlayout in "Single Pages" mode or if a retqlayout is pending
+ // relayout in "Single Pages" mode or if a relayout is pending
d->blockPixmapsRequest = true;
if ( !KpdfSettings::viewContinuous() || d->dirtyLayout )
slotRelayoutPages();
- // restore viewport center or use default {x-center,v-top} tqalignment
- const TQRect & r = item->tqgeometry();
+ // restore viewport center or use default {x-center,v-top} alignment
+ const TQRect & r = item->geometry();
int newCenterX = r.left(),
newCenterY = r.top();
if ( vp.rePos.enabled )
@@ -462,13 +462,13 @@ void PageView::notifyPageChanged( int pageNumber, int changedFlags )
if ( changedFlags & DocumentObserver::Bookmark )
return;
// iterate over visible items: if page(pageNumber) is one of them, tqrepaint it
TQValueList< PageViewItem * >::iterator iIt = d->visibleItems.begin(), iEnd = d->visibleItems.end();
for ( ; iIt != iEnd; ++iIt )
if ( (*iIt)->pageNumber() == pageNumber )
{
// update item's rectangle plus the little outline
- TQRect expandedRect = (*iIt)->tqgeometry();
+ TQRect expandedRect = (*iIt)->geometry();
expandedRect.addCoords( -1, -1, 3, 3 );
updateContents( expandedRect );
@@ -535,7 +535,7 @@ void PageView::viewportPaintEvent( TQPaintEvent * pe )
d->selectionRectColor : TQt::red;
// subdivide region into rects
- TQMemArray<TQRect> allRects = TQRegion(pe->region()).tqrects();
+ TQMemArray<TQRect> allRects = TQRegion(pe->region()).rects();
uint numRects = allRects.count();
// preprocess rects area to see if it worths or not using subdivision
@@ -592,7 +592,7 @@ void PageView::viewportPaintEvent( TQPaintEvent * pe )
TQImage blendedImage = blendedPixmap.convertToImage();
KImageEffect::blend( selBlendColor.dark(140), blendedImage, 0.2 );
// copy the blended pixmap back to its place
- pixmapPainter.tqdrawPixmap( blendRect.left(), blendRect.top(), blendedImage );
+ pixmapPainter.drawPixmap( blendRect.left(), blendRect.top(), blendedImage );
}
// draw border (red if the selection is too small)
pixmapPainter.setPen( selBlendColor );
@@ -618,7 +618,7 @@ void PageView::viewportPaintEvent( TQPaintEvent * pe )
if ( !selectionRect.isNull() && selectionRect.intersects( contentsRect ) &&
!selectionRectInternal.contains( contentsRect ) )
{
- screenPainter.setPen( tqpalette().active().highlight().dark(110) );
+ screenPainter.setPen( palette().active().highlight().dark(110) );
screenPainter.drawRect( selectionRect );
}
// 4) Layer 3: overlays
@@ -662,7 +662,7 @@ void PageView::keyPressEvent( TQKeyEvent * e )
bool found = d->document->searchText( PAGEVIEW_SEARCH_ID, d->typeAheadString, true, false,
KPDFDocument::NextMatch, true, tqRgb( 128, 255, 128 ), true );
TQString status = found ? i18n("Text found: \"%1\".") : i18n("Text not found: \"%1\".");
- d->messageWindow->display( status.tqarg(d->typeAheadString.lower()),
+ d->messageWindow->display( status.arg(d->typeAheadString.lower()),
found ? PageViewMessage::Find : PageViewMessage::Warning, 4000 );
d->findTimeoutTimer->start( 3000, true );
}
@@ -682,7 +682,7 @@ void PageView::keyPressEvent( TQKeyEvent * e )
// because it activates the accel
releaseKeyboard();
if ( d->document->continueSearch( PAGEVIEW_SEARCH_ID ) )
- d->messageWindow->display( i18n("Text found: \"%1\".").tqarg(d->typeAheadString.lower()),
+ d->messageWindow->display( i18n("Text found: \"%1\".").arg(d->typeAheadString.lower()),
PageViewMessage::Find, 3000 );
d->findTimeoutTimer->start( 3000, true );
// it is needed to grab the keyboard becase people may have Space assigned to a
@@ -847,7 +847,7 @@ void PageView::contentsMouseMoveEvent( TQMouseEvent * e )
d->zoomFactor *= ( 1.0 + ( (double)deltaY / 500.0 ) );
updateZoom( ZoomRefreshCurrent );
// uncomment following line to force a complete redraw
- viewport()->tqrepaint( false );
+ viewport()->repaint( false );
return;
}
@@ -876,7 +876,7 @@ void PageView::contentsMouseMoveEvent( TQMouseEvent * e )
{
d->aPrevAction = d->aMouseNormal;
d->aMouseSelect->activate();
- TQColor selColor = tqpalette().active().highlight().light( 120 );
+ TQColor selColor = palette().active().highlight().light( 120 );
selectionStart( e->x() + deltaX, e->y() + deltaY, selColor, false );
selectionEndPoint( e->x(), e->y() );
break;
@@ -946,7 +946,7 @@ void PageView::contentsMousePressEvent( TQMouseEvent * e )
case MouseZoom: // set first corner of the zoom rect
if ( leftButton )
- selectionStart( e->x(), e->y(), tqpalette().active().highlight(), false );
+ selectionStart( e->x(), e->y(), palette().active().highlight(), false );
else if ( rightButton )
updateZoom( ZoomOut );
break;
@@ -954,7 +954,7 @@ void PageView::contentsMousePressEvent( TQMouseEvent * e )
case MouseSelect: // set first corner of the selection rect
if ( leftButton )
{
- TQColor selColor = tqpalette().active().highlight().light( 120 );
+ TQColor selColor = palette().active().highlight().light( 120 );
selectionStart( e->x(), e->y(), selColor, false );
}
break;
@@ -1006,8 +1006,8 @@ void PageView::contentsMouseReleaseEvent( TQMouseEvent * e )
// if the mouse has not moved since the press, that's a -click-
if ( leftButton && pageItem && d->mousePressPos == e->globalPos())
{
- double nX = (double)(e->x() - pageItem->tqgeometry().left()) / (double)pageItem->width(),
- nY = (double)(e->y() - pageItem->tqgeometry().top()) / (double)pageItem->height();
+ double nX = (double)(e->x() - pageItem->geometry().left()) / (double)pageItem->width(),
+ nY = (double)(e->y() - pageItem->geometry().top()) / (double)pageItem->height();
const ObjectRect * linkRect, * imageRect;
linkRect = pageItem->page()->hasObject( ObjectRect::Link, nX, nY );
if ( linkRect )
@@ -1105,16 +1105,16 @@ void PageView::contentsMouseReleaseEvent( TQMouseEvent * e )
for ( ; iIt != iEnd; ++iIt )
{
PageViewItem * item = *iIt;
- const TQRect & tqitemRect = item->tqgeometry();
- if ( selectionRect.intersects( tqitemRect ) )
+ const TQRect & itemRect = item->geometry();
+ if ( selectionRect.intersects( itemRect ) )
{
// request the textpage if there isn't one
const KPDFPage * kpdfPage = item->page();
if ( !kpdfPage->hasSearchPage() )
d->document->requestTextPage( kpdfPage->number() );
- // grab text in the rect that intersects tqitemRect
- TQRect relativeRect = selectionRect.intersect( tqitemRect );
- relativeRect.moveBy( -tqitemRect.left(), -tqitemRect.top() );
+ // grab text in the rect that intersects itemRect
+ TQRect relativeRect = selectionRect.intersect( itemRect );
+ relativeRect.moveBy( -itemRect.left(), -itemRect.top() );
NormalizedRect normRect( relativeRect, item->width(), item->height() );
selectedText += kpdfPage->getText( normRect );
}
@@ -1131,7 +1131,7 @@ void PageView::contentsMouseReleaseEvent( TQMouseEvent * e )
if ( KpdfSettings::useKTTSD() )
menu.insertItem( SmallIcon("kttsd"), i18n( "Speak Text" ), 2 );
}
- menu.insertTitle( i18n( "Image (%1 by %2 pixels)" ).tqarg( selectionRect.width() ).tqarg( selectionRect.height() ) );
+ menu.insertTitle( i18n( "Image (%1 by %2 pixels)" ).arg( selectionRect.width() ).arg( selectionRect.height() ) );
menu.insertItem( SmallIcon("image"), i18n( "Copy to Clipboard" ), 3 );
menu.insertItem( SmallIcon("filesave"), i18n( "Save to File..." ), 4 );
int choice = menu.exec( e->globalPos() );
@@ -1147,11 +1147,11 @@ void PageView::contentsMouseReleaseEvent( TQMouseEvent * e )
if ( choice == 3 )
{
// [2] copy pixmap to clipboard
- TQClipboard *cb = TQApplication::tqclipboard();
+ TQClipboard *cb = TQApplication::clipboard();
cb->setPixmap( copyPix, TQClipboard::Clipboard );
if ( cb->supportsSelection() )
cb->setPixmap( copyPix, TQClipboard::Selection );
- d->messageWindow->display( i18n( "Image [%1x%2] copied to clipboard." ).tqarg( copyPix.width() ).tqarg( copyPix.height() ) );
+ d->messageWindow->display( i18n( "Image [%1x%2] copied to clipboard." ).arg( copyPix.width() ).arg( copyPix.height() ) );
}
else if ( choice == 4 )
{
@@ -1165,7 +1165,7 @@ void PageView::contentsMouseReleaseEvent( TQMouseEvent * e )
if ( type.isNull() )
type = "PNG";
copyPix.save( fileName, type.latin1() );
- d->messageWindow->display( i18n( "Image [%1x%2] saved to %3 file." ).tqarg( copyPix.width() ).tqarg( copyPix.height() ).tqarg( type ) );
+ d->messageWindow->display( i18n( "Image [%1x%2] saved to %3 file." ).arg( copyPix.width() ).arg( copyPix.height() ).arg( type ) );
}
}
}
@@ -1175,7 +1175,7 @@ void PageView::contentsMouseReleaseEvent( TQMouseEvent * e )
if ( choice == 1 )
{
// [1] copy text to clipboard
- TQClipboard *cb = TQApplication::tqclipboard();
+ TQClipboard *cb = TQApplication::clipboard();
cb->setText( selectedText, TQClipboard::Clipboard );
if ( cb->supportsSelection() )
cb->setText( selectedText, TQClipboard::Selection );
@@ -1194,7 +1194,7 @@ void PageView::contentsMouseReleaseEvent( TQMouseEvent * e )
TQString error;
if (KApplication::startServiceByDesktopName("kttsd", TQStringList(), &error))
{
- d->messageWindow->display( i18n("Starting KTTSD Failed: %1").tqarg(error) );
+ d->messageWindow->display( i18n("Starting KTTSD Failed: %1").arg(error) );
KpdfSettings::setUseKTTSD(false);
KpdfSettings::writeConfig();
}
@@ -1221,7 +1221,7 @@ void PageView::contentsMouseReleaseEvent( TQMouseEvent * e )
}
}
- // clear widget selection and tqinvalidate rect
+ // clear widget selection and invalidate rect
selectionClear();
// restore previous action if came from it using right button
@@ -1323,17 +1323,17 @@ void PageView::paintItems( TQPainter * p, const TQRect & contentsRect )
for ( ; iIt != iEnd; ++iIt )
{
// check if a piece of the page intersects the contents rect
- if ( !(*iIt)->tqgeometry().intersects( checkRect ) )
+ if ( !(*iIt)->geometry().intersects( checkRect ) )
continue;
PageViewItem * item = *iIt;
- TQRect pixmapGeometry = item->tqgeometry();
+ TQRect pixmapGeometry = item->geometry();
// translate the painter so we draw top-left pixmap corner in 0,0
p->save();
p->translate( pixmapGeometry.left(), pixmapGeometry.top() );
- // item pixmap and outline tqgeometry
+ // item pixmap and outline geometry
TQRect outlineGeometry = pixmapGeometry;
outlineGeometry.addCoords( -1, -1, 3, 3 );
@@ -1378,7 +1378,7 @@ void PageView::paintItems( TQPainter * p, const TQRect & contentsRect )
}
// paint with background color the unpainted area
- TQMemArray<TQRect> backRects = remainingArea.tqrects();
+ TQMemArray<TQRect> backRects = remainingArea.rects();
uint backRectsNumber = backRects.count();
for ( uint jr = 0; jr < backRectsNumber; jr++ )
p->fillRect( backRects[ jr ], TQt::gray );
@@ -1424,7 +1424,7 @@ PageViewItem * PageView::pickItemOnPoint( int x, int y )
for ( ; iIt != iEnd; ++iIt )
{
PageViewItem * i = *iIt;
- const TQRect & r = i->tqgeometry();
+ const TQRect & r = i->geometry();
if ( x < r.right() && x > r.left() && y < r.bottom() )
{
if ( y > r.top() )
@@ -1485,7 +1485,7 @@ void PageView::selectionEndPoint( int x, int y )
compoundRegion -= intersection;
}
// tassellate region with rects and enqueue paint events
- TQMemArray<TQRect> rects = compoundRegion.tqrects();
+ TQMemArray<TQRect> rects = compoundRegion.rects();
for ( uint i = 0; i < rects.count(); i++ )
updateContents( rects[i] );
}
@@ -1544,7 +1544,7 @@ void PageView::updateZoom( ZoomMode newZoomMode )
if ( newZoomMode != d->zoomMode || (newZoomMode == ZoomFixed && newFactor != d->zoomFactor ) )
{
- // rebuild tqlayout and update the whole viewport
+ // rebuild layout and update the whole viewport
d->zoomMode = newZoomMode;
d->zoomFactor = newFactor;
// be sure to block updates to document's viewport
@@ -1599,7 +1599,7 @@ void PageView::updateZoomText()
selIdx++;
TQString localValue( KGlobal::locale()->formatNumber( value * 100.0, 2 ) );
localValue.remove( KGlobal::locale()->decimalSymbol() + double_oh );
- translated << TQString( "%1%" ).tqarg( localValue );
+ translated << TQString( "%1%" ).arg( localValue );
}
d->aZoom->setItems( translated );
@@ -1619,8 +1619,8 @@ void PageView::updateCursor( const TQPoint &p )
PageViewItem * pageItem = pickItemOnPoint( p.x(), p.y() );
if ( pageItem && d->mouseMode == MouseNormal )
{
- double nX = (double)(p.x() - pageItem->tqgeometry().left()) / (double)pageItem->width(),
- nY = (double)(p.y() - pageItem->tqgeometry().top()) / (double)pageItem->height();
+ double nX = (double)(p.x() - pageItem->geometry().left()) / (double)pageItem->width(),
+ nY = (double)(p.y() - pageItem->geometry().top()) / (double)pageItem->height();
// if over a ObjectRect (of type Link) change cursor to hand
d->mouseOnRect = pageItem->page()->hasObject( ObjectRect::Link, nX, nY );
@@ -1643,7 +1643,7 @@ void PageView::doTypeAheadSearch()
bool found = d->document->searchText( PAGEVIEW_SEARCH_ID, d->typeAheadString, false, false,
KPDFDocument::NextMatch, true, tqRgb( 128, 255, 128 ), true );
TQString status = found ? i18n("Text found: \"%1\".") : i18n("Text not found: \"%1\".");
- d->messageWindow->display( status.tqarg(d->typeAheadString.lower()),
+ d->messageWindow->display( status.arg(d->typeAheadString.lower()),
found ? PageViewMessage::Find : PageViewMessage::Warning, 4000 );
d->findTimeoutTimer->start( 3000, true );
}
@@ -1677,7 +1677,7 @@ void PageView::slotRelayoutPages()
fullHeight = 0;
TQRect viewportRect( contentsX(), contentsY(), viewportWidth, viewportHeight );
- // set all items tqgeometry and resize contents. handle 'continuous' and 'single' modes separately
+ // set all items geometry and resize contents. handle 'continuous' and 'single' modes separately
if ( KpdfSettings::viewContinuous() )
{
// Here we find out column's width and row's height to compute a table
@@ -1816,11 +1816,11 @@ void PageView::slotRelayoutPages()
{
int prevX = contentsX(),
prevY = contentsY();
- const TQRect & tqgeometry = d->items[ vp.pageNumber ]->tqgeometry();
+ const TQRect & geometry = d->items[ vp.pageNumber ]->geometry();
double nX = vp.rePos.enabled ? vp.rePos.normalizedX : 0.5,
nY = vp.rePos.enabled ? vp.rePos.normalizedY : 0.0;
- center( tqgeometry.left() + ROUND( nX * (double)tqgeometry.width() ),
- tqgeometry.top() + ROUND( nY * (double)tqgeometry.height() ) );
+ center( geometry.left() + ROUND( nX * (double)geometry.width() ),
+ geometry.top() + ROUND( nY * (double)geometry.height() ) );
// center() usually moves the viewport, that requests pixmaps too.
// if that doesn't happen we have to request them by hand
if ( prevX == contentsX() && prevY == contentsY() )
@@ -1867,7 +1867,7 @@ void PageView::slotRequestVisiblePixmaps( int newLeft, int newTop )
PageViewItem * i = *iIt;
// if the item doesn't intersect the viewport, skip it
- if ( !viewportRect.intersects( i->tqgeometry() ) )
+ if ( !viewportRect.intersects( i->geometry() ) )
continue;
// add the item to the 'visible list'
@@ -1885,18 +1885,18 @@ void PageView::slotRequestVisiblePixmaps( int newLeft, int newTop )
// position between the item and the viewport center
if ( isEvent )
{
- const TQRect & tqgeometry = i->tqgeometry();
+ const TQRect & geometry = i->geometry();
// compute distance between item center and viewport center
- double distance = hypot( (tqgeometry.left() + tqgeometry.right()) / 2 - viewportCenterX,
- (tqgeometry.top() + tqgeometry.bottom()) / 2 - viewportCenterY );
+ double distance = hypot( (geometry.left() + geometry.right()) / 2 - viewportCenterX,
+ (geometry.top() + geometry.bottom()) / 2 - viewportCenterY );
if ( distance >= minDistance && nearPageNumber != -1 )
continue;
nearPageNumber = i->pageNumber();
minDistance = distance;
- if ( tqgeometry.height() > 0 && tqgeometry.width() > 0 )
+ if ( geometry.height() > 0 && geometry.width() > 0 )
{
- focusedX = ( viewportCenterX - (double)tqgeometry.left() ) / (double)tqgeometry.width();
- focusedY = ( viewportCenterY - (double)tqgeometry.top() ) / (double)tqgeometry.height();
+ focusedX = ( viewportCenterX - (double)geometry.left() ) / (double)geometry.width();
+ focusedY = ( viewportCenterY - (double)geometry.top() ) / (double)geometry.height();
}
}
}
@@ -462,13 +462,13 @@ void PageView::notifyPageChanged( int pageNumber, int changedFlags )
if ( changedFlags & DocumentObserver::Bookmark )
return;
- // iterate over visible items: if page(pageNumber) is one of them, tqrepaint it
+ // iterate over visible items: if page(pageNumber) is one of them, repaint it
TQValueList< PageViewItem * >::iterator iIt = d->visibleItems.begin(), iEnd = d->visibleItems.end();
for ( ; iIt != iEnd; ++iIt )
diff --git a/kpdf/ui/pageviewutils.cpp b/kpdf/ui/pageviewutils.cpp
index a948d49c..ce657882 100644
--- a/kpdf/ui/pageviewutils.cpp
+++ b/kpdf/ui/pageviewutils.cpp
@@ -27,7 +27,7 @@ PageViewMessage::PageViewMessage( TQWidget * parent )
setFocusPolicy( TQ_NoFocus );
setBackgroundMode( NoBackground );
setPaletteBackgroundColor(kapp->palette().color(TQPalette::Active, TQColorGroup::Background));
- // if the tqlayout is LtR, we can safely place it in the right position
+ // if the layout is LtR, we can safely place it in the right position
if ( !TQApplication::reverseLayout() )
move( 10, 10 );
resize( 0, 0 );
@@ -54,7 +54,7 @@ void PageViewMessage::display( const TQString & message, Icon icon, int duration
iconXOffset = 0,
shadowOffset = 1;
// load icon (if set) and update tqgeometry
TQPixmap symbol;
if ( icon != None )
{
@@ -84,44 +84,44 @@ void PageViewMessage::display( const TQString & message, Icon icon, int duration
width += 2 + symbol.width();
height = TQMAX( height, symbol.height() );
}
- TQRect tqgeometry( 0, 0, width + 10, height + 8 );
+ TQRect geometry( 0, 0, width + 10, height + 8 );
// resize pixmap, mask and widget
static TQBitmap mask;
- mask.resize( tqgeometry.size() );
- m_pixmap.resize( tqgeometry.size() );
- resize( tqgeometry.size() );
+ mask.resize( geometry.size() );
+ m_pixmap.resize( geometry.size() );
+ resize( geometry.size() );
// create and set transparency mask
TQPainter maskPainter( &mask);
mask.fill( TQt::black );
maskPainter.setBrush( TQt::white );
- maskPainter.drawRoundRect( tqgeometry, 1600 / tqgeometry.width(), 1600 / tqgeometry.height() );
+ maskPainter.drawRoundRect( geometry, 1600 / geometry.width(), 1600 / geometry.height() );
setMask( mask );
// draw background
TQPainter bufferPainter( &m_pixmap );
bufferPainter.setPen( TQt::black );
bufferPainter.setBrush( paletteBackgroundColor() );
- bufferPainter.drawRoundRect( tqgeometry, 1600 / tqgeometry.width(), 1600 / tqgeometry.height() );
+ bufferPainter.drawRoundRect( geometry, 1600 / geometry.width(), 1600 / geometry.height() );
// draw icon if present
if ( !symbol.isNull() )
bufferPainter.drawPixmap( 5 + iconXOffset, 4, symbol, 0, 0, symbol.width(), symbol.height() );
// draw shadow and text
- int yText = tqgeometry.height() - height / 2;
+ int yText = geometry.height() - height / 2;
bufferPainter.setPen( paletteBackgroundColor().dark( 115 ) );
bufferPainter.drawText( 5 + textXOffset + shadowOffset, yText + 1, message );
bufferPainter.setPen( foregroundColor() );
bufferPainter.drawText( 5 + textXOffset, yText, message );
- // if the tqlayout is RtL, we can move it to the right place only after we
+ // if the layout is RtL, we can move it to the right place only after we
// know how much size it will take
if ( TQApplication::reverseLayout() )
- move( parentWidget()->width() - tqgeometry.width() - 10, 10 );
+ move( parentWidget()->width() - geometry.width() - 10, 10 );
- // show widget and schedule a tqrepaint
+ // show widget and schedule a repaint
show();
update();
@@ -168,19 +168,19 @@ int PageViewItem::pageNumber() const
return m_page->number();
}
-const TQRect& PageViewItem::tqgeometry() const
+const TQRect& PageViewItem::geometry() const
{
- return m_tqgeometry;
+ return m_geometry;
}
int PageViewItem::width() const
{
- return m_tqgeometry.width();
+ return m_geometry.width();
}
int PageViewItem::height() const
{
- return m_tqgeometry.height();
+ return m_geometry.height();
}
double PageViewItem::zoomFactor() const
@@ -190,18 +190,18 @@ double PageViewItem::zoomFactor() const
void PageViewItem::setGeometry( int x, int y, int width, int height )
{
- m_tqgeometry.setRect( x, y, width, height );
+ m_geometry.setRect( x, y, width, height );
}
void PageViewItem::setWHZ( int w, int h, double z )
{
- m_tqgeometry.setWidth( w );
- m_tqgeometry.setHeight( h );
+ m_geometry.setWidth( w );
+ m_geometry.setHeight( h );
m_zoomFactor = z;
}
void PageViewItem::moveTo( int x, int y )
{
- m_tqgeometry.moveLeft( x );
- m_tqgeometry.moveTop( y );
+ m_geometry.moveLeft( x );
+ m_geometry.moveTop( y );
}
@@ -54,7 +54,7 @@ void PageViewMessage::display( const TQString & message, Icon icon, int duration
iconXOffset = 0,
shadowOffset = 1;
- // load icon (if set) and update tqgeometry
+ // load icon (if set) and update geometry
TQPixmap symbol;
if ( icon != None )
diff --git a/kpdf/ui/pageviewutils.h b/kpdf/ui/pageviewutils.h
index ceac9fe2..68c2f08b 100644
--- a/kpdf/ui/pageviewutils.h
+++ b/kpdf/ui/pageviewutils.h
@@ -23,7 +23,7 @@ class KPDFPage;
/**
* @short PageViewItem represents graphically a kpdfpage into the PageView.
*
* It has methods for settings Item's tqgeometry and other visual properties such
* as the individual zoom factor.
*/
class PageViewItem
@@ -33,7 +33,7 @@ class PageViewItem
const KPDFPage * page() const;
int pageNumber() const;
- const TQRect& tqgeometry() const;
+ const TQRect& geometry() const;
int width() const;
int height() const;
double zoomFactor() const;
@@ -45,7 +45,7 @@ class PageViewItem
private:
const KPDFPage * m_page;
double m_zoomFactor;
- TQRect m_tqgeometry;
+ TQRect m_geometry;
};
@@ -23,7 +23,7 @@ class KPDFPage;
* @short PageViewItem represents graphically a kpdfpage into the PageView.
*
- * It has methods for settings Item's tqgeometry and other visual properties such
+ * It has methods for settings Item's geometry and other visual properties such
* as the individual zoom factor.
*/